==> tecfy_basic_package-1.0.26.tar.gz: lib/views/components/text_form_feild.dart <==
part of tecfy_basic_package;

class AppTextFormField extends StatelessWidget {
  final TextInputAction? textInputAction;
  final TextEditingController? controller;
  final String? Function(String?)? validator;
  final String? regExp;
  final String? validateMessage;
  final void Function()? onEditingComplete;
  final void Function(String)? onFieldSubmitted;
  final AutovalidateMode? autovalidateMode;

  /// must assign controller to user on text changed
  final void Function(String)? onTextChanged;
  final TextInputType? keyboardType;
  final String? labelText;
  final String? description;
  final bool isRequired;
  final Widget? icon;
  final bool obscureText;
  final bool autoFocus;
  final int maxLines;
  final FocusNode? focusNode;
  final bool isDarkBackgound;
  final TextDirection? textDirection;
  final TextStyle? textStyle;
  final bool? enabled;
  final InputDecoration? decoration;
  final BoxDecoration? decorationIos;
  AppTextFormField(
      {this.textInputAction,
      this.controller,
      this.regExp,
      this.decoration,
      this.autovalidateMode,
      this.decorationIos,
      this.validateMessage,
      this.isDarkBackgound = false,
      this.icon,
      this.textDirection,
      this.validator,
      this.keyboardType,
      this.labelText,
      this.description,
      this.isRequired = false,
      this.onEditingComplete,
      this.onTextChanged,
      this.focusNode,
      this.enabled,
      this.obscureText = false,
      this.autoFocus = false,
      this.onFieldSubmitted,
      this.maxLines = 1,
      this.textStyle}) {
    if (onTextChanged != null && controller != null) {
      controller!.addListener(() {
        onTextChanged!(controller!.text);
      });
    }
  }

  TextStyle get defaultTextStyle => TextStyle(
      color: isDarkBackgound ? Colors.white : ThemeService.mainTextColor);

  @override
  Widget build(BuildContext context) {
    Widget result;
    if (maxLines > 1)
      result = getMultiRowText(context);
    else
      result = icon == null
          ? getSingleRowText(context)
          : Stack(children: <Widget>[
              getSingleRowText(context),
              Container(
                  height: 60,
                  padding: EdgeInsets.only(right: 10, left: 10),
                  child: Align(
                      child: icon,
                      alignment: ConfigService.isRTL
                          ? Alignment.centerLeft
                          : Alignment.centerRight))
            ]);

    return isDarkBackgound
        ? Theme(child: result, data: ThemeData.dark())
        : result;
  }

  Widget getSingleRowText(context) {
    return Theme.of(context).platform == TargetPlatform.iOS
        ? Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: <Widget>[
                Text(
                  '$labelText ${isRequired ? '*' : ''}',
                  style: TextStyle(
                      fontSize: 12.0,
                      color: isDarkBackgound ? Colors.white : Colors.black38),
                ),
                CupertinoTextField(
                    controller: controller,
                    textInputAction: textInputAction,
                    keyboardType: keyboardType,
                    //validator: validator,
                    onEditingComplete: onEditingComplete,
                    obscureText: obscureText,
                    enabled: enabled,
                    maxLines: maxLines,
                    placeholder: labelText,
                    focusNode: focusNode,
                    autofocus: autoFocus,
                    onSubmitted: onFieldSubmitted,
                    style: textStyle ?? defaultTextStyle,
                    decoration: BoxDecoration()),
                Container(
                    height: 1.0,
                    color: isDarkBackgound ? Colors.white : Colors.black),
                SizedBox(height: 15.0)
              ])
        : TextFormField(
            autovalidateMode: autovalidateMode,
            textDirection: textDirection,
            enableInteractiveSelection: !obscureText,
            textInputAction: textInputAction,
            keyboardType: keyboardType,
            controller: controller,
            onEditingComplete: onEditingComplete,
            focusNode: focusNode,
            validator: validator ??
                (val) {
                  if (val == null || val.isEmpty)
                    return isRequired
                        ? this.validateMessage ?? 'Required'
                        : null;
                  if (this.regExp == null) return null;
                  if (!RegExp(this.regExp!).hasMatch(val)) {
                    return this.validateMessage ?? 'Error';
                  }
                },
            obscureText: obscureText,
            maxLines: maxLines,
            autofocus: autoFocus,
            enabled: enabled,
            style: textStyle ?? defaultTextStyle,
            onFieldSubmitted: onFieldSubmitted,
            enableSuggestions: true,
            decoration: decoration?.copyWith(
                    labelText: isRequired ? '$labelText*' : labelText,
                    helperText: description) ??
                InputDecoration(
                  helperText: description,
                  labelText: isRequired ? '$labelText*' : labelText,
                  border: UnderlineInputBorder(),
                ),
          );
  }

  Widget getMultiRowText(context) {
    return Theme.of(context).platform == TargetPlatform.iOS
        ? Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: <Widget>[
                Text('$labelText ${isRequired ? '*' : ''}',
                    style: TextStyle(fontSize: 12.0)),
                SizedBox(height: 5.9),
                Container(
                    height: 25.0 * maxLines,
                    decoration: decorationIos ??
                        ShapeDecoration(
                            shape: RoundedRectangleBorder(
                                borderRadius:
                                    BorderRadius.all(Radius.circular(2.0)),
                                side: BorderSide(color: Colors.black38))),
                    child: Scrollbar(
                        child: SingleChildScrollView(
                            child: CupertinoTextField(
                                controller: controller,
                                onEditingComplete: onEditingComplete,
                                focusNode: focusNode,
                                textInputAction: textInputAction,
                                keyboardType: TextInputType.multiline,
                                obscureText: obscureText,
                                maxLines: 5,
                                enabled: enabled,
                                placeholder: labelText,
                                style: textStyle ?? defaultTextStyle,
                                decoration: BoxDecoration()))))
              ])
        : TextFormField(
            autovalidateMode: autovalidateMode,
            textDirection: textDirection,
            enableInteractiveSelection: true,
            textInputAction: textInputAction,
            keyboardType: TextInputType.multiline,
            controller: controller,
            onEditingComplete: onEditingComplete,
            validator: validator ??
                (val) {
                  if (val == null || val.isEmpty)
                    return isRequired
                        ? this.validateMessage ?? 'Required'
                        : null;
                  if (this.regExp == null) return null;
                  if (!RegExp(this.regExp!).hasMatch(val)) {
                    return this.validateMessage ?? 'Error';
                  }
                },
            obscureText: obscureText,
            enabled: enabled,
            focusNode: focusNode,
            maxLines: maxLines,
            style: textStyle ?? defaultTextStyle,
            decoration: decoration?.copyWith(
                    labelText: isRequired ? '$labelText*' : labelText,
                    helperText: description) ??
                InputDecoration(
                    helperText: description,
                    labelText: isRequired ? '$labelText*' : labelText),
          );
  }
}

==> tecfy_basic_package-1.1.8.tar.gz: lib/views/components/text_form_feild.dart <==
part of tecfy_basic_package;

class AppTextFormField extends StatelessWidget {
  final TextInputAction? textInputAction;
  final TextEditingController? controller;
  final String? Function(String?)? validator;
  final String? regExp;
  final String? validateMessage;
  final void Function()? onEditingComplete;
  final void Function(String)? onFieldSubmitted;
  final AutovalidateMode? autovalidateMode;

  /// must assign controller to user on text changed
  final void Function(String)? onTextChanged;
  final TextInputType? keyboardType;
  final String? labelText;
  final String? description;
  final bool isRequired;
  final Widget? icon;
  final bool obscureText;
  final bool autoFocus;
  final int? maxLines;
  final int? minLines;
  final FocusNode? focusNode;
  final bool isDarkBackgound;
  final TextDirection? textDirection;
  final TextStyle? textStyle;
  final bool? enabled;
  final InputDecoration? decoration;
  final BoxDecoration? decorationIos;
  AppTextFormField(
      {this.textInputAction,
      this.controller,
      this.regExp,
      this.decoration,
      this.autovalidateMode,
      this.decorationIos,
      this.validateMessage,
      this.isDarkBackgound = false,
      this.icon,
      this.textDirection,
      this.validator,
      this.keyboardType,
      this.labelText,
      this.description,
      this.isRequired = false,
      this.onEditingComplete,
      this.onTextChanged,
      this.focusNode,
      this.enabled,
      this.obscureText = false,
      this.autoFocus = false,
      this.onFieldSubmitted,
      this.maxLines = 1,
      this.minLines,
      this.textStyle}) {
    if (onTextChanged != null && controller != null) {
      controller!.addListener(() {
        onTextChanged!(controller!.text);
      });
    }
  }

  TextStyle get defaultTextStyle => TextStyle(
      color: isDarkBackgound ? Colors.white : ThemeService.mainTextColor);

  @override
  Widget build(BuildContext context) {
    Widget result;
    if (maxLines == null || maxLines! > 1)
      result = getMultiRowText(context);
    else
      result = icon == null
          ? getSingleRowText(context)
          : Stack(children: <Widget>[
              getSingleRowText(context),
              Container(
                  height: 60,
                  padding: EdgeInsets.only(right: 10, left: 10),
                  child: Align(
                      child: icon,
                      alignment: ConfigService.isRTL
                          ? Alignment.centerLeft
                          : Alignment.centerRight))
            ]);

    return isDarkBackgound
        ? Theme(child: result, data: ThemeData.dark())
        : result;
  }

  Widget getSingleRowText(context) {
    return !kIsWeb && Theme.of(context).platform == TargetPlatform.iOS
        ? Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: <Widget>[
                labelText == null
                    ? const SizedBox()
                    : Text(
                        '$labelText ${isRequired ? '*' : ''}',
                        style: TextStyle(
                            fontSize: 12.0,
                            color: isDarkBackgound
                                ? Colors.white
                                : Colors.black38),
                      ),
                CupertinoTextField(
                    controller: controller,
                    textInputAction: textInputAction,
                    keyboardType: keyboardType,
                    //validator: validator,
                    onEditingComplete: onEditingComplete,
                    obscureText: obscureText,
                    enabled: enabled,
                    maxLines: maxLines,
                    minLines: minLines,
                    placeholder: labelText,
                    focusNode: focusNode,
                    autofocus: autoFocus,
                    onSubmitted: onFieldSubmitted,
                    style: textStyle ?? defaultTextStyle,
                    decoration: BoxDecoration()),
                Container(
                    height: 1.0,
                    color: isDarkBackgound ? Colors.white : Colors.black),
                SizedBox(height: 15.0)
              ])
        : TextFormField(
            autovalidateMode: autovalidateMode,
            textDirection: textDirection,
            enableInteractiveSelection: !obscureText,
            textInputAction: textInputAction,
            keyboardType: keyboardType,
            controller: controller,
            onEditingComplete: onEditingComplete,
            focusNode: focusNode,
            validator: validator ??
                (val) {
                  if (val == null || val.isEmpty)
                    return isRequired
                        ? this.validateMessage ?? 'Required'
                        : null;
                  if (this.regExp == null) return null;
                  if (!RegExp(this.regExp!).hasMatch(val)) {
                    return this.validateMessage ?? 'Error';
                  }
                },
            obscureText: obscureText,
            maxLines: maxLines,
            minLines: minLines,
            autofocus: autoFocus,
            enabled: enabled,
            style: textStyle ?? defaultTextStyle,
            onFieldSubmitted: onFieldSubmitted,
            enableSuggestions: true,
            decoration: decoration?.copyWith(
                    labelText: isRequired ? '$labelText*' : labelText,
                    helperText: description) ??
                InputDecoration(
                  helperText: description,
                  labelText: isRequired ? '$labelText*' : labelText,
                  border: UnderlineInputBorder(),
                ),
          );
  }

  Widget getMultiRowText(context) {
    return !kIsWeb && Theme.of(context).platform == TargetPlatform.iOS
        ? Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: <Widget>[
                labelText == null
                    ? const SizedBox()
                    : Text('$labelText ${isRequired ? '*' : ''}',
                        style: TextStyle(fontSize: 12.0)),
                SizedBox(height: 5.9),
                Container(
                    height: maxLines == null ? null : 25.0 * maxLines!,
                    decoration: decorationIos ??
                        ShapeDecoration(
                            shape: RoundedRectangleBorder(
                                borderRadius:
                                    BorderRadius.all(Radius.circular(2.0)),
                                side: BorderSide(color: Colors.black38))),
                    child: Scrollbar(
                        child: SingleChildScrollView(
                            child: CupertinoTextField(
                                controller: controller,
                                onEditingComplete: onEditingComplete,
                                focusNode: focusNode,
                                textInputAction: textInputAction,
                                keyboardType: TextInputType.multiline,
                                obscureText: obscureText,
                                maxLines: maxLines,
                                minLines: minLines,
                                enabled: enabled,
                                placeholder: labelText,
                                style: textStyle ?? defaultTextStyle,
                                decoration: BoxDecoration()))))
              ])
        : TextFormField(
            autovalidateMode: autovalidateMode,
            textDirection: textDirection,
            enableInteractiveSelection: true,
            textInputAction: textInputAction,
            keyboardType: TextInputType.multiline,
            controller: controller,
            onEditingComplete: onEditingComplete,
            validator: validator ??
                (val) {
                  if (val == null || val.isEmpty)
                    return isRequired
                        ? this.validateMessage ?? 'Required'
                        : null;
                  if (this.regExp == null) return null;
                  if (!RegExp(this.regExp!).hasMatch(val)) {
                    return this.validateMessage ?? 'Error';
                  }
                },
            obscureText: obscureText,
            enabled: enabled,
            focusNode: focusNode,
            maxLines: maxLines,
            minLines: minLines,
            style: textStyle ?? defaultTextStyle,
            decoration: decoration?.copyWith(
                    labelText: isRequired ? '$labelText*' : labelText,
                    helperText: description) ??
                InputDecoration(
                    helperText: description,
                    labelText: isRequired ? '$labelText*' : labelText),
          );
  }
}
